@@ -8,6 +8,8 @@ import uuid
 import xml.etree.ElementTree as ET
 from concurrent.futures import ThreadPoolExecutor
 
+from .chapterizer import clean_file_string
+
 import requests
 
 from os.path import (abspath, basename, expanduser, getsize, isdir, isfile, sep)
@@ -110,10 +112,12 @@ class Downloader:
             logger.debug('Could not download cover. Status code: {}'.format(
                 r.status_code))
 
+
     def _extract_author_title_urls_parts(self, odm_filename):
         odm_root, metadata = self._get_odm_root_and_metadata(odm_filename)
         author = self._get_author_from_metadata(metadata)
         title = metadata.findtext('Title')
+        title = clean_file_string(title)
         cover_url = metadata.findtext('CoverUrl', '')
         logger.info('Got title "{}" and author'.format(title)
                      + ('s' if ';' in author else '')
